@@ -27,8 +27,8 @@
 #include <libedataserver/libedataserver.h>
 
 #include <libecal/e-cal-client-view.h>
+#include <libecal/e-cal-enums.h>
 #include <libecal/e-cal-recur.h>
-#include <libecal/e-cal-types.h>
 #include <libecal/e-cal-util.h>
 
 /* Standard GObject macros */
@@ -51,35 +51,35 @@
 	((obj), E_TYPE_CAL_CLIENT, ECalClientClass))
 
 /**
- * CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS:
+ * E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS:
  *
  * An email address associated with the calendar.
  *
  * Since: 3.2
  **/
-#define CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS		"cal-email-address"
+#define E_CAL_BACKEND_PROPERTY_CAL_EMAIL_ADDRESS	"cal-email-address"
 
 /**
- * CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS:
+ * E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS:
  *
  * An email address preferred for e-mail reminders by the calendar.
  *
  * Since: 3.2
  **/
-#define CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS	"alarm-email-address"
+#define E_CAL_BACKEND_PROPERTY_ALARM_EMAIL_ADDRESS	"alarm-email-address"
 
 /**
- * CAL_BACKEND_PROPERTY_DEFAULT_OBJECT:
+ * E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT:
  *
  * A default object for the calendar. Calendars use VEVENT, memo lists VJOURNAL
  * and task lists VTODO, which can have prefilled values by the backend.
  *
  * Since: 3.2
  **/
-#define CAL_BACKEND_PROPERTY_DEFAULT_OBJECT		"default-object"
+#define E_CAL_BACKEND_PROPERTY_DEFAULT_OBJECT		"default-object"
 
 /**
- * CAL_BACKEND_PROPERTY_REVISION:
+ * E_CAL_BACKEND_PROPERTY_REVISION:
  *
  * The current overall revision string, this can be used as
  * a quick check to see if data has changed at all since the
@@ -87,7 +87,7 @@
  *
  * Since: 3.4
  **/
-#define CAL_BACKEND_PROPERTY_REVISION			"revision"
+#define E_CAL_BACKEND_PROPERTY_REVISION			"revision"
 
 /**
  * E_CAL_CLIENT_ERROR:
@@ -121,6 +121,14 @@ typedef enum {
 	E_CAL_CLIENT_ERROR_INVALID_RANGE
 } ECalClientError;
 
+GQuark		e_cal_client_error_quark	(void) G_GNUC_CONST;
+const gchar *	e_cal_client_error_to_string	(ECalClientError code);
+GError *	e_cal_client_error_create	(ECalClientError code,
+						 const gchar *custom_msg);
+GError *	e_cal_client_error_create_fmt	(ECalClientError code,
+						 const gchar *format,
+						 ...) G_GNUC_PRINTF (2, 3);
+
 typedef struct _ECalClient ECalClient;
 typedef struct _ECalClientClass ECalClientClass;
 typedef struct _ECalClientPrivate ECalClientPrivate;
@@ -153,12 +161,9 @@ struct _ECalClientClass {
 	/*< public >*/
 	/* Signals */
 	void		(*free_busy_data)	(ECalClient *client,
-						 const GSList *free_busy_ecalcomps);
+						 const GSList *free_busy_ecalcomps); /* ECalComponent * */
 };
 
-GQuark		e_cal_client_error_quark	(void) G_GNUC_CONST;
-const gchar *	e_cal_client_error_to_string	(ECalClientError code);
-
 GType		e_cal_client_get_type		(void) G_GNUC_CONST;
 EClient *	e_cal_client_connect_sync	(ESource *source,
 						 ECalClientSourceType source_type,
@@ -179,8 +184,8 @@ const gchar *	e_cal_client_get_local_attachment_store
 						(ECalClient *client);
 void		e_cal_client_set_default_timezone
 						(ECalClient *client,
-						 icaltimezone *zone);
-icaltimezone *	e_cal_client_get_default_timezone
+						 ICalTimezone *zone);
+ICalTimezone *	e_cal_client_get_default_timezone
 						(ECalClient *client);
 gboolean	e_cal_client_check_one_alarm_only
 						(ECalClient *client);
@@ -192,49 +197,41 @@ gboolean	e_cal_client_check_organizer_must_accept
 						(ECalClient *client);
 gboolean	e_cal_client_check_recurrences_no_master
 						(ECalClient *client);
-void		e_cal_client_free_icalcomp_slist
-						(GSList *icalcomps);
-void		e_cal_client_free_ecalcomp_slist
-						(GSList *ecalcomps);
 
-icaltimezone *	e_cal_client_resolve_tzid_cb	(const gchar *tzid,
-						 gpointer data);
-icaltimezone *	e_cal_client_resolve_tzid_sync	(const gchar *tzid,
-						 gpointer cal_client,
-						 GCancellable *cancellable,
-						 GError **error);
 void		e_cal_client_generate_instances	(ECalClient *client,
 						 time_t start,
 						 time_t end,
 						 GCancellable *cancellable,
-						 ECalRecurInstanceFn cb,
+						 ECalRecurInstanceCb cb,
 						 gpointer cb_data,
 						 GDestroyNotify destroy_cb_data);
 void		e_cal_client_generate_instances_sync
 						(ECalClient *client,
 						 time_t start,
 						 time_t end,
-						 ECalRecurInstanceFn cb,
+						 GCancellable *cancellable,
+						 ECalRecurInstanceCb cb,
 						 gpointer cb_data);
 void		e_cal_client_generate_instances_for_object
 						(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
 						 time_t start,
 						 time_t end,
 						 GCancellable *cancellable,
-						 ECalRecurInstanceFn cb,
+						 ECalRecurInstanceCb cb,
 						 gpointer cb_data,
 						 GDestroyNotify destroy_cb_data);
 void		e_cal_client_generate_instances_for_object_sync
 						(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
 						 time_t start,
 						 time_t end,
-						 ECalRecurInstanceFn cb,
+						 GCancellable *cancellable,
+						 ECalRecurInstanceCb cb,
 						 gpointer cb_data);
 gchar *		e_cal_client_get_component_as_string
 						(ECalClient *client,
-						 icalcomponent *icalcomp);
+						 ICalComponent *icalcomp);
 void		e_cal_client_get_default_object	(ECalClient *client,
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
@@ -242,11 +239,11 @@ void		e_cal_client_get_default_object	(ECalClient *client,
 gboolean	e_cal_client_get_default_object_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 icalcomponent **out_icalcomp,
+						 ICalComponent **out_icalcomp,
 						 GError **error);
 gboolean	e_cal_client_get_default_object_sync
 						(ECalClient *client,
-						 icalcomponent **out_icalcomp,
+						 ICalComponent **out_icalcomp,
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_get_object		(ECalClient *client,
@@ -257,12 +254,12 @@ void		e_cal_client_get_object		(ECalClient *client,
 						 gpointer user_data);
 gboolean	e_cal_client_get_object_finish	(ECalClient *client,
 						 GAsyncResult *result,
-						 icalcomponent **out_icalcomp,
+						 ICalComponent **out_icalcomp,
 						 GError **error);
 gboolean	e_cal_client_get_object_sync	(ECalClient *client,
 						 const gchar *uid,
 						 const gchar *rid,
-						 icalcomponent **out_icalcomp,
+						 ICalComponent **out_icalcomp,
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_get_objects_for_uid
@@ -274,12 +271,12 @@ void		e_cal_client_get_objects_for_uid
 gboolean	e_cal_client_get_objects_for_uid_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 GSList **out_ecalcomps,
+						 GSList **out_ecalcomps, /* ECalComponent * */
 						 GError **error);
 gboolean	e_cal_client_get_objects_for_uid_sync
 						(ECalClient *client,
 						 const gchar *uid,
-						 GSList **out_ecalcomps,
+						 GSList **out_ecalcomps, /* ECalComponent * */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_get_object_list	(ECalClient *client,
@@ -290,12 +287,12 @@ void		e_cal_client_get_object_list	(ECalClient *client,
 gboolean	e_cal_client_get_object_list_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 GSList **out_icalcomps,
+						 GSList **out_icalcomps, /* ICalComponent * */
 						 GError **error);
 gboolean	e_cal_client_get_object_list_sync
 						(ECalClient *client,
 						 const gchar *sexp,
-						 GSList **out_icalcomps,
+						 GSList **out_icalcomps, /* ICalComponent * */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_get_object_list_as_comps
@@ -307,35 +304,36 @@ void		e_cal_client_get_object_list_as_comps
 gboolean	e_cal_client_get_object_list_as_comps_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 GSList **out_ecalcomps,
+						 GSList **out_ecalcomps, /* ECalComponent * */
 						 GError **error);
 gboolean	e_cal_client_get_object_list_as_comps_sync
 						(ECalClient *client,
 						 const gchar *sexp,
-						 GSList **out_ecalcomps,
+						 GSList **out_ecalcomps, /* ECalComponent * */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_get_free_busy	(ECalClient *client,
 						 time_t start,
 						 time_t end,
-						 const GSList *users,
+						 const GSList *users, /* gchar * */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
 gboolean	e_cal_client_get_free_busy_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 GSList **out_freebusy,
+						 GSList **out_freebusy, /* ECalComponent * */
 						 GError **error);
 gboolean	e_cal_client_get_free_busy_sync	(ECalClient *client,
 						 time_t start,
 						 time_t end,
-						 const GSList *users,
-						 GSList **out_freebusy,
+						 const GSList *users, /* gchar * */
+						 GSList **out_freebusy, /* ECalComponent * */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_create_object	(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -345,29 +343,33 @@ gboolean	e_cal_client_create_object_finish
 						 gchar **out_uid,
 						 GError **error);
 gboolean	e_cal_client_create_object_sync	(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 gchar **out_uid,
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_create_objects	(ECalClient *client,
-						 GSList *icalcomps,
+						 GSList *icalcomps, /* ICalComponent * */
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
 gboolean	e_cal_client_create_objects_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 GSList **out_uids,
+						 GSList **out_uids, /* gchar * */
 						 GError **error);
 gboolean	e_cal_client_create_objects_sync
 						(ECalClient *client,
-						 GSList *icalcomps,
-						 GSList **out_uids,
+						 GSList *icalcomps, /* ICalComponent * */
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
+						 GSList **out_uids, /* gchar * */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_modify_object	(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -376,13 +378,15 @@ gboolean	e_cal_client_modify_object_finish
 						 GAsyncResult *result,
 						 GError **error);
 gboolean	e_cal_client_modify_object_sync	(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_modify_objects	(ECalClient *client,
-						 GSList *comps,
+						 GSList *icalcomps, /* ICalComponent * */
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -392,14 +396,16 @@ gboolean	e_cal_client_modify_objects_finish
 						 GError **error);
 gboolean	e_cal_client_modify_objects_sync
 						(ECalClient *client,
-						 GSList *comps,
+						 GSList *icalcomps, /* ICalComponent * */
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_remove_object	(ECalClient *client,
 						 const gchar *uid,
 						 const gchar *rid,
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -411,11 +417,13 @@ gboolean	e_cal_client_remove_object_sync	(ECalClient *client,
 						 const gchar *uid,
 						 const gchar *rid,
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_remove_objects	(ECalClient *client,
-						 const GSList *ids,
+						 const GSList *ids, /* ECalComponentId * */
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -425,12 +433,14 @@ gboolean	e_cal_client_remove_objects_finish
 						 GError **error);
 gboolean	e_cal_client_remove_objects_sync
 						(ECalClient *client,
-						 const GSList *ids,
+						 const GSList *ids, /* ECalComponentId * */
 						 ECalObjModType mod,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_receive_objects	(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -440,24 +450,27 @@ gboolean	e_cal_client_receive_objects_finish
 						 GError **error);
 gboolean	e_cal_client_receive_objects_sync
 						(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_send_objects	(ECalClient *client,
-						 icalcomponent *icalcomp,
+						 ICalComponent *icalcomp,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
 gboolean	e_cal_client_send_objects_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 GSList **out_users,
-						 icalcomponent **out_modified_icalcomp,
+						 GSList **out_users, /* gchar * */
+						 ICalComponent **out_modified_icalcomp,
 						 GError **error);
 gboolean	e_cal_client_send_objects_sync	(ECalClient *client,
-						 icalcomponent *icalcomp,
-						 GSList **out_users,
-						 icalcomponent **out_modified_icalcomp,
+						 ICalComponent *icalcomp,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
+						 GSList **out_users, /* gchar * */
+						 ICalComponent **out_modified_icalcomp,
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_get_attachment_uris
@@ -470,19 +483,20 @@ void		e_cal_client_get_attachment_uris
 gboolean	e_cal_client_get_attachment_uris_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 GSList **out_attachment_uris,
+						 GSList **out_attachment_uris, /* gchar * */
 						 GError **error);
 gboolean	e_cal_client_get_attachment_uris_sync
 						(ECalClient *client,
 						 const gchar *uid,
 						 const gchar *rid,
-						 GSList **out_attachment_uris,
+						 GSList **out_attachment_uris, /* gchar * */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_discard_alarm	(ECalClient *client,
 						 const gchar *uid,
 						 const gchar *rid,
 						 const gchar *auid,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -494,6 +508,7 @@ gboolean	e_cal_client_discard_alarm_sync	(ECalClient *client,
 						 const gchar *uid,
 						 const gchar *rid,
 						 const gchar *auid,
+						 guint32 opflags, /* bit-or of ECalOperationFlags */
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_get_view		(ECalClient *client,
@@ -518,15 +533,15 @@ void		e_cal_client_get_timezone	(ECalClient *client,
 gboolean	e_cal_client_get_timezone_finish
 						(ECalClient *client,
 						 GAsyncResult *result,
-						 icaltimezone **out_zone,
+						 ICalTimezone **out_zone,
 						 GError **error);
 gboolean	e_cal_client_get_timezone_sync	(ECalClient *client,
 						 const gchar *tzid,
-						 icaltimezone **out_zone,
+						 ICalTimezone **out_zone,
 						 GCancellable *cancellable,
 						 GError **error);
 void		e_cal_client_add_timezone	(ECalClient *client,
-						 icaltimezone *zone,
+						 ICalTimezone *zone,
 						 GCancellable *cancellable,
 						 GAsyncReadyCallback callback,
 						 gpointer user_data);
@@ -535,18 +550,10 @@ gboolean	e_cal_client_add_timezone_finish
 						 GAsyncResult *result,
 						 GError **error);
 gboolean	e_cal_client_add_timezone_sync	(ECalClient *client,
-						 icaltimezone *zone,
+						 ICalTimezone *zone,
 						 GCancellable *cancellable,
 						 GError **error);
 
-#ifndef EDS_DISABLE_DEPRECATED
-ECalClient *	e_cal_client_new		(ESource *source,
-						 ECalClientSourceType source_type,
-						 GError **error);
-GError *	e_cal_client_error_create	(ECalClientError code,
-						 const gchar *custom_msg);
-#endif /* EDS_DISABLE_DEPRECATED */
-
 G_END_DECLS
 
 #endif /* E_CAL_CLIENT_H */
